# dynamax

![Logo](https://raw.githubusercontent.com/probml/dynamax/main/logo/logo.gif)

![Test Status](https://github.com/probml/dynamax/actions/workflows/run_tests.yml/badge.svg?branch=main)

Dynamic State Space Models in JAX.

Documentation is at https://probml.github.io/dynamax/.

***Note: the code is currently under active development, and the API will soon change. Please wait for the official release
on 11/14/22 before using.***


Core team: Peter Chang, Giles Harper-Donnelly, Aleyna Kara, Xinglong Li, Scott Linderman, Kevin Murphy.

Other contributors: Adrien Corenflos, Elizabeth DuPre, Gerardo Duran-Martin, Colin Schlager and other people [listed here](https://github.com/probml/dynamax/graphs/contributors)

MIT License. 2022






